pexpect: Python module for controlling and automating other programs
====================================================================

Description
-----------

Pexpect is a pure Python module for spawning child applications;
controlling them; and responding to expected patterns in their output.

License
-------

ISC license: http://opensource.org/licenses/isc-license.txt This license
is approved by the OSI and FSF as GPL-compatible.


Upstream Contact
----------------

- http://pexpect.readthedocs.org/en/stable/
- https://github.com/pexpect/pexpect

